@@ -94,7 +94,7 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 			if (strncmp(temp_string, "cpu MHz", strlen("cpu MHz")) == 0)
 				tempMHz = atol(temp_string2);
 
-			if (strncmp(temp_string, "BogoMips", strlen("BogoMips")) == 0)
+			if (strncasecmp(temp_string, "BogoMips", strlen("BogoMips")) == 0)
 				bogomips = bogomips + atof(temp_string2);
 		}
 
